#import <Foundation/Foundation.h>
#import "OAIForwardMessageRequest.h"
#import "OAIMessages.h"
#import "OAISendContactRequest.h"
#import "OAISendFileRequest.h"
#import "OAISendLinkRequest.h"
#import "OAISendLocationRequest.h"
#import "OAISendMessageRequest.h"
#import "OAISendMessageStatus.h"
#import "OAISendPTTRequest.h"
#import "OAISendVCardRequest.h"
#import "OAIApi.h"

/**
* Chat API SDK
* The SDK allows you to receive and send messages through your WhatsApp account. [Sign up now](https://app.chat-api.com/)  The Chat API is based on the WhatsApp WEB protocol and excludes the ban both when using libraries from mgp25 and the like. Despite this, your account can be banned by anti-spam system WhatsApp after several clicking the \"block\" button.
*
* The version of the OpenAPI document: 1.0.0
* Contact: sale@chat-api.com
*
* NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
* https://openapi-generator.tech
* Do not edit the class manually.
*/



@interface OAIClass2MessagesApi: NSObject <OAIApi>

extern NSString* kOAIClass2MessagesApiErrorDomain;
extern NSInteger kOAIClass2MessagesApiMissingParamErrorCode;

-(instancetype) initWithApiClient:(OAIApiClient *)apiClient NS_DESIGNATED_INITIALIZER;

/// Forwarding messages to a new or existing chat.
/// Only one of two parameters is needed to determine the destination - chatId or phone.
///
/// @param forwardMessageRequest 
/// 
///  code:200 message:"Server response example"
///
/// @return OAISendMessageStatus*
-(NSURLSessionTask*) forwardMessageWithForwardMessageRequest: (OAIForwardMessageRequest*) forwardMessageRequest
    completionHandler: (void (^)(OAISendMessageStatus* output, NSError* error)) handler;


/// Get a list of messages.
/// To receive only new messages, pass the **lastMessageNumber** parameter from the last query.  Files from messages are guaranteed to be stored only for 30 days and can be deleted. Download the files as soon as you get to your server.
///
/// @param lastMessageNumber The lastMessageNumber parameter from the last response (optional)
/// @param last Displays the last 100 messages. If this parameter is passed, then lastMessageNumber is ignored. (optional) (default to @(NO))
/// @param chatId Filter messages by chatId  Chat ID from the message list. Examples: 17633123456@c.us for private messages and 17680561234-1479621234@g.us for the group. (optional)
/// @param limit Sets length of the message list. Default 100. With value 0 returns all messages. (optional)
/// @param minTime Filter messages received after specified time. Example: 946684800. (optional)
/// @param maxTime Filter messages received before specified time. Example: 946684800. (optional)
/// 
///  code:200 message:"Server response example"
///
/// @return OAIMessages*
-(NSURLSessionTask*) getMessagesWithLastMessageNumber: (NSNumber*) lastMessageNumber
    last: (NSNumber*) last
    chatId: (NSString*) chatId
    limit: (NSNumber*) limit
    minTime: (NSNumber*) minTime
    maxTime: (NSNumber*) maxTime
    completionHandler: (void (^)(OAIMessages* output, NSError* error)) handler;


/// Sending a contact or contact list to a new or existing chat.
/// Only one of two parameters is needed to determine the destination - chatId or phone.
///
/// @param sendContactRequest 
/// 
///  code:200 message:"Server response example"
///
/// @return OAISendMessageStatus*
-(NSURLSessionTask*) sendContactWithSendContactRequest: (OAISendContactRequest*) sendContactRequest
    completionHandler: (void (^)(OAISendMessageStatus* output, NSError* error)) handler;


/// Send a file to a new or existing chat.
/// Only one of two parameters is needed to determine the destination - chatId or phone.
///
/// @param sendFileRequest 
/// 
///  code:200 message:"Server response example"
///
/// @return OAISendMessageStatus*
-(NSURLSessionTask*) sendFileWithSendFileRequest: (OAISendFileRequest*) sendFileRequest
    completionHandler: (void (^)(OAISendMessageStatus* output, NSError* error)) handler;


/// Send text with link and link's preview to a new or existing chat.
/// Only one of two parameters is needed to determine the destination - chatId or phone.
///
/// @param sendLinkRequest 
/// 
///  code:200 message:"Server response example"
///
/// @return OAISendMessageStatus*
-(NSURLSessionTask*) sendLinkWithSendLinkRequest: (OAISendLinkRequest*) sendLinkRequest
    completionHandler: (void (^)(OAISendMessageStatus* output, NSError* error)) handler;


/// Sending a location to a new or existing chat.
/// Only one of two parameters is needed to determine the destination - chatId or phone.
///
/// @param sendLocationRequest 
/// 
///  code:200 message:"Server response example"
///
/// @return OAISendMessageStatus*
-(NSURLSessionTask*) sendLocationWithSendLocationRequest: (OAISendLocationRequest*) sendLocationRequest
    completionHandler: (void (^)(OAISendMessageStatus* output, NSError* error)) handler;


/// Send a message to a new or existing chat.
/// The message will be added to the queue for sending and delivered even if the phone is disconnected from the Internet or authorization is not passed.  Only one of two parameters is needed to determine the destination - chatId or phone.
///
/// @param sendMessageRequest 
/// 
///  code:200 message:"Server response example"
///
/// @return OAISendMessageStatus*
-(NSURLSessionTask*) sendMessageWithSendMessageRequest: (OAISendMessageRequest*) sendMessageRequest
    completionHandler: (void (^)(OAISendMessageStatus* output, NSError* error)) handler;


/// Send a ptt-audio to a new or existing chat.
/// Only one of two parameters is needed to determine the destination - chatId or phone.
///
/// @param sendPTTRequest 
/// 
///  code:200 message:"Server response example"
///
/// @return OAISendMessageStatus*
-(NSURLSessionTask*) sendPTTWithSendPTTRequest: (OAISendPTTRequest*) sendPTTRequest
    completionHandler: (void (^)(OAISendMessageStatus* output, NSError* error)) handler;


/// Sending a vcard to a new or existing chat.
/// Only one of two parameters is needed to determine the destination - chatId or phone.
///
/// @param sendVCardRequest 
/// 
///  code:200 message:"Server response example"
///
/// @return OAISendMessageStatus*
-(NSURLSessionTask*) sendVCardWithSendVCardRequest: (OAISendVCardRequest*) sendVCardRequest
    completionHandler: (void (^)(OAISendMessageStatus* output, NSError* error)) handler;



@end
