# OAIClass1InstanceApi

All URIs are relative to *https://api.chat-api.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**expiry**](OAIClass1InstanceApi.md#expiry) | **POST** /expiry | Updates the QR code after its expired
[**getQRCode**](OAIClass1InstanceApi.md#getqrcode) | **GET** /qr_code | Direct link to QR-code in the form of an image, not base64.
[**getSettings**](OAIClass1InstanceApi.md#getsettings) | **GET** /settings | Get settings
[**getStatus**](OAIClass1InstanceApi.md#getstatus) | **GET** /status | Get the account status and QR code for authorization.
[**logout**](OAIClass1InstanceApi.md#logout) | **POST** /logout | Logout from WhatsApp Web to get new QR code.
[**reboot**](OAIClass1InstanceApi.md#reboot) | **POST** /reboot | Reboot your whatsapp instance.
[**retry**](OAIClass1InstanceApi.md#retry) | **POST** /retry | Repeat the manual synchronization attempt with the device
[**setSettings**](OAIClass1InstanceApi.md#setsettings) | **POST** /settings | Set settings
[**takeover**](OAIClass1InstanceApi.md#takeover) | **POST** /takeover | Returns the active session if the device has connected another instance of Web WhatsApp


# **expiry**
```objc
-(NSURLSessionTask*) expiryWithCompletionHandler: 
        (void (^)(OAIInlineResponse2002* output, NSError* error)) handler;
```

Updates the QR code after its expired

### Example 
```objc
OAIDefaultConfiguration *apiConfig = [OAIDefaultConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: instanceId)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"instanceId"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"instanceId"];

// Configure API key authorization: (authentication scheme: token)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"token"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"token"];



OAIClass1InstanceApi*apiInstance = [[OAIClass1InstanceApi alloc] init];

// Updates the QR code after its expired
[apiInstance expiryWithCompletionHandler: 
          ^(OAIInlineResponse2002* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling OAIClass1InstanceApi->expiry: %@", error);
                        }
                    }];
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**OAIInlineResponse2002***](OAIInlineResponse2002.md)

### Authorization

[instanceId](../README.md#instanceId), [token](../README.md#token)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getQRCode**
```objc
-(NSURLSessionTask*) getQRCodeWithCompletionHandler: 
        (void (^)(NSURL* output, NSError* error)) handler;
```

Direct link to QR-code in the form of an image, not base64.

### Example 
```objc
OAIDefaultConfiguration *apiConfig = [OAIDefaultConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: instanceId)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"instanceId"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"instanceId"];

// Configure API key authorization: (authentication scheme: token)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"token"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"token"];



OAIClass1InstanceApi*apiInstance = [[OAIClass1InstanceApi alloc] init];

// Direct link to QR-code in the form of an image, not base64.
[apiInstance getQRCodeWithCompletionHandler: 
          ^(NSURL* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling OAIClass1InstanceApi->getQRCode: %@", error);
                        }
                    }];
```

### Parameters
This endpoint does not need any parameter.

### Return type

**NSURL***

### Authorization

[instanceId](../README.md#instanceId), [token](../README.md#token)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: image/png

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getSettings**
```objc
-(NSURLSessionTask*) getSettingsWithCompletionHandler: 
        (void (^)(OAISettings* output, NSError* error)) handler;
```

Get settings

**webhookUrl** - Http or https URL for receiving notifications. For testing, we recommend using [our RequestBin](http://bin.chat-api.com).  **ackNotificationsOn** - Turn on/off ack (message delivered and message viewed) notifications in webhooks. GET method works for the same address.  **chatUpdateOn** - Turn on/off chat update notifications in webhooks. GET method works for the same address.  **videoUploadOn** - Turn on/off receiving video messages.  **proxy** - Socks5 IP address and port proxy for instance.  **guaranteedHooks** - Guarantee webhook delivery. Each webhook will make 20 attempts to send until it receives 200 status from the server.  **ignoreOldMessages** - Do not send webhooks with old messages during authorization.  **processArchive** - Process messages from archived chats.  **instanceStatuses** - Turn on/off collecting instance status changing history.  **webhookStatuses** - Turn on/off collecting messages webhooks statuses.  **statusNotificationsOn** - Turn on/off instance changind status notifications in webhooks.

### Example 
```objc
OAIDefaultConfiguration *apiConfig = [OAIDefaultConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: instanceId)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"instanceId"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"instanceId"];

// Configure API key authorization: (authentication scheme: token)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"token"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"token"];



OAIClass1InstanceApi*apiInstance = [[OAIClass1InstanceApi alloc] init];

// Get settings
[apiInstance getSettingsWithCompletionHandler: 
          ^(OAISettings* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling OAIClass1InstanceApi->getSettings: %@", error);
                        }
                    }];
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**OAISettings***](OAISettings.md)

### Authorization

[instanceId](../README.md#instanceId), [token](../README.md#token)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getStatus**
```objc
-(NSURLSessionTask*) getStatusWithFull: (NSNumber*) full
    noWakeup: (NSNumber*) noWakeup
        completionHandler: (void (^)(OAIInstanceStatus* output, NSError* error)) handler;
```

Get the account status and QR code for authorization.

Reauthorization is necessary only in case of changing the device or manually pressing \"Logout on all devices\" on the phone. Keep the WhastsApp application open during authorization.  Instance statuses:  **authenticated** -  Authorization passed successfully  **init** -  Initial status   **loading** -  The system is still loading, try again in 1 minute   **got qr code** -  There is a QR code and you need to take a picture of it in the Whatsapp application by going to Menu -> WhatsApp Web -> Add. QR code is valid for one minute.   [Example showing base64 images on a page.](https://stackoverflow.com/questions/31526085/how-to-encode-an-image-into-an-html-file)  Manually easier to get [QR-code as an image](/#getQRCode)    When you request the status of the instance in standby mode (status **\"init\"**), it will automatically turn on. To avoid this behavior, use the **no_wakeup** parameter

### Example 
```objc
OAIDefaultConfiguration *apiConfig = [OAIDefaultConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: instanceId)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"instanceId"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"instanceId"];

// Configure API key authorization: (authentication scheme: token)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"token"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"token"];


NSNumber* full = true; // Get full information on the current status (optional) (default to @(NO))
NSNumber* noWakeup = true; // Ignore autowakeup (optional) (default to @(NO))

OAIClass1InstanceApi*apiInstance = [[OAIClass1InstanceApi alloc] init];

// Get the account status and QR code for authorization.
[apiInstance getStatusWithFull:full
              noWakeup:noWakeup
          completionHandler: ^(OAIInstanceStatus* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling OAIClass1InstanceApi->getStatus: %@", error);
                        }
                    }];
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **full** | **NSNumber***| Get full information on the current status | [optional] [default to @(NO)]
 **noWakeup** | **NSNumber***| Ignore autowakeup | [optional] [default to @(NO)]

### Return type

[**OAIInstanceStatus***](OAIInstanceStatus.md)

### Authorization

[instanceId](../README.md#instanceId), [token](../README.md#token)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **logout**
```objc
-(NSURLSessionTask*) logoutWithCompletionHandler: 
        (void (^)(OAIInlineResponse200* output, NSError* error)) handler;
```

Logout from WhatsApp Web to get new QR code.

### Example 
```objc
OAIDefaultConfiguration *apiConfig = [OAIDefaultConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: instanceId)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"instanceId"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"instanceId"];

// Configure API key authorization: (authentication scheme: token)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"token"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"token"];



OAIClass1InstanceApi*apiInstance = [[OAIClass1InstanceApi alloc] init];

// Logout from WhatsApp Web to get new QR code.
[apiInstance logoutWithCompletionHandler: 
          ^(OAIInlineResponse200* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling OAIClass1InstanceApi->logout: %@", error);
                        }
                    }];
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**OAIInlineResponse200***](OAIInlineResponse200.md)

### Authorization

[instanceId](../README.md#instanceId), [token](../README.md#token)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **reboot**
```objc
-(NSURLSessionTask*) rebootWithCompletionHandler: 
        (void (^)(OAIInlineResponse2004* output, NSError* error)) handler;
```

Reboot your whatsapp instance.

### Example 
```objc
OAIDefaultConfiguration *apiConfig = [OAIDefaultConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: instanceId)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"instanceId"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"instanceId"];

// Configure API key authorization: (authentication scheme: token)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"token"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"token"];



OAIClass1InstanceApi*apiInstance = [[OAIClass1InstanceApi alloc] init];

// Reboot your whatsapp instance.
[apiInstance rebootWithCompletionHandler: 
          ^(OAIInlineResponse2004* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling OAIClass1InstanceApi->reboot: %@", error);
                        }
                    }];
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**OAIInlineResponse2004***](OAIInlineResponse2004.md)

### Authorization

[instanceId](../README.md#instanceId), [token](../README.md#token)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **retry**
```objc
-(NSURLSessionTask*) retryWithCompletionHandler: 
        (void (^)(OAIInlineResponse2003* output, NSError* error)) handler;
```

Repeat the manual synchronization attempt with the device

### Example 
```objc
OAIDefaultConfiguration *apiConfig = [OAIDefaultConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: instanceId)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"instanceId"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"instanceId"];

// Configure API key authorization: (authentication scheme: token)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"token"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"token"];



OAIClass1InstanceApi*apiInstance = [[OAIClass1InstanceApi alloc] init];

// Repeat the manual synchronization attempt with the device
[apiInstance retryWithCompletionHandler: 
          ^(OAIInlineResponse2003* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling OAIClass1InstanceApi->retry: %@", error);
                        }
                    }];
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**OAIInlineResponse2003***](OAIInlineResponse2003.md)

### Authorization

[instanceId](../README.md#instanceId), [token](../README.md#token)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **setSettings**
```objc
-(NSURLSessionTask*) setSettingsWithSettings: (OAISettings*) settings
        completionHandler: (void (^)(OAIInlineResponse2005* output, NSError* error)) handler;
```

Set settings

**webhookUrl** - Http or https URL for receiving notifications. For testing, we recommend using [our RequestBin](http://bin.chat-api.com).  **ackNotificationsOn** - Turn on/off ack (message delivered and message viewed) notifications in webhooks. GET method works for the same address.  **chatUpdateOn** - Turn on/off chat update notifications in webhooks. GET method works for the same address.  **videoUploadOn** - Turn on/off receiving video messages.  **proxy** - Socks5 IP address and port proxy for instance.  **guaranteedHooks** - Guarantee webhook delivery. Each webhook will make 20 attempts to send until it receives 200 status from the server.  **ignoreOldMessages** - Do not send webhooks with old messages during authorization.  **processArchive** - Process messages from archived chats.  **instanceStatuses** - Turn on/off collecting instance status changing history.  **webhookStatuses** - Turn on/off collecting messages webhooks statuses.  **statusNotificationsOn** - Turn on/off instance changind status notifications in webhooks.

### Example 
```objc
OAIDefaultConfiguration *apiConfig = [OAIDefaultConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: instanceId)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"instanceId"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"instanceId"];

// Configure API key authorization: (authentication scheme: token)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"token"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"token"];


OAISettings* settings = [[OAISettings alloc] init]; // 

OAIClass1InstanceApi*apiInstance = [[OAIClass1InstanceApi alloc] init];

// Set settings
[apiInstance setSettingsWithSettings:settings
          completionHandler: ^(OAIInlineResponse2005* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling OAIClass1InstanceApi->setSettings: %@", error);
                        }
                    }];
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **settings** | [**OAISettings***](OAISettings.md)|  | 

### Return type

[**OAIInlineResponse2005***](OAIInlineResponse2005.md)

### Authorization

[instanceId](../README.md#instanceId), [token](../README.md#token)

### HTTP request headers

 - **Content-Type**: application/json, application/x-www-form-urlencoded
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **takeover**
```objc
-(NSURLSessionTask*) takeoverWithCompletionHandler: 
        (void (^)(OAIInlineResponse2001* output, NSError* error)) handler;
```

Returns the active session if the device has connected another instance of Web WhatsApp

### Example 
```objc
OAIDefaultConfiguration *apiConfig = [OAIDefaultConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: instanceId)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"instanceId"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"instanceId"];

// Configure API key authorization: (authentication scheme: token)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"token"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"token"];



OAIClass1InstanceApi*apiInstance = [[OAIClass1InstanceApi alloc] init];

// Returns the active session if the device has connected another instance of Web WhatsApp
[apiInstance takeoverWithCompletionHandler: 
          ^(OAIInlineResponse2001* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling OAIClass1InstanceApi->takeover: %@", error);
                        }
                    }];
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**OAIInlineResponse2001***](OAIInlineResponse2001.md)

### Authorization

[instanceId](../README.md#instanceId), [token](../README.md#token)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

