# OAIClass7TestingApi

All URIs are relative to *https://api.chat-api.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**instanceStatuses**](OAIClass7TestingApi.md#instancestatuses) | **GET** /instanceStatuses | Returns instance status changes history.
[**webhookStatuses**](OAIClass7TestingApi.md#webhookstatuses) | **GET** /webhookStatus | Returns webhook status for message.


# **instanceStatuses**
```objc
-(NSURLSessionTask*) instanceStatusesWithMinTime: (NSNumber*) minTime
    maxTime: (NSNumber*) maxTime
        completionHandler: (void (^)(OAIStatuses* output, NSError* error)) handler;
```

Returns instance status changes history.

Requires enable \"instanceStatuses\" option for collecting data.

### Example 
```objc
OAIDefaultConfiguration *apiConfig = [OAIDefaultConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: instanceId)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"instanceId"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"instanceId"];

// Configure API key authorization: (authentication scheme: token)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"token"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"token"];


NSNumber* minTime = 946684800; // Filter statuses received after specified date. Example: 946684800. (optional)
NSNumber* maxTime = 946684800; // Filter statuses received before specified date. Example: 946684800. (optional)

OAIClass7TestingApi*apiInstance = [[OAIClass7TestingApi alloc] init];

// Returns instance status changes history.
[apiInstance instanceStatusesWithMinTime:minTime
              maxTime:maxTime
          completionHandler: ^(OAIStatuses* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling OAIClass7TestingApi->instanceStatuses: %@", error);
                        }
                    }];
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **minTime** | **NSNumber***| Filter statuses received after specified date. Example: 946684800. | [optional] 
 **maxTime** | **NSNumber***| Filter statuses received before specified date. Example: 946684800. | [optional] 

### Return type

[**OAIStatuses***](OAIStatuses.md)

### Authorization

[instanceId](../README.md#instanceId), [token](../README.md#token)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **webhookStatuses**
```objc
-(NSURLSessionTask*) webhookStatusesWithMsgId: (NSString*) msgId
        completionHandler: (void (^)(OAIWebhookStatus* output, NSError* error)) handler;
```

Returns webhook status for message.

Requires enable \"webhookStatuses\" option for collecting data.

### Example 
```objc
OAIDefaultConfiguration *apiConfig = [OAIDefaultConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: instanceId)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"instanceId"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"instanceId"];

// Configure API key authorization: (authentication scheme: token)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"token"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"token"];


NSString* msgId = false_17472822486@c.us_DF38E6A25B42CC8CCE57EC40F; // Message ID. Example: false_17472822486@c.us_DF38E6A25B42CC8CCE57EC40F.

OAIClass7TestingApi*apiInstance = [[OAIClass7TestingApi alloc] init];

// Returns webhook status for message.
[apiInstance webhookStatusesWithMsgId:msgId
          completionHandler: ^(OAIWebhookStatus* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling OAIClass7TestingApi->webhookStatuses: %@", error);
                        }
                    }];
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **msgId** | **NSString***| Message ID. Example: false_17472822486@c.us_DF38E6A25B42CC8CCE57EC40F. | 

### Return type

[**OAIWebhookStatus***](OAIWebhookStatus.md)

### Authorization

[instanceId](../README.md#instanceId), [token](../README.md#token)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

